<?php

namespace App\Http\Controllers;

use App\Models\ColdDrink;
use Illuminate\Http\Request;
use Validator;

class ColdDrinksController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function viewDrink()
    {
        try {
            $data = ColdDrink::orderBy('created_at', 'DESC')->get();
            return response()->json(['status' => 'success', 'data' => $data]);
        } catch (\Throwable $th) {

            return response()->json(['status' => 'failed', 'msg' => "No Data Found!!"]);
        }
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function addDrink(Request $request)
    {
        //validate incoming request 
        $validator = Validator::make($request->all(), [
            'name' => 'required|unique:products|max:25',
            'image' => 'required|image|mimes:jpeg,jpg,png,gif',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => 'val_err', 'val_err' => $validator->errors()]);
        } else {
            try {
                if ($request->hasFile('image')) {
                    $extension = "." . $request->image->getClientOriginalExtension();
                    $name = basename($request->image->getClientOriginalName(), $extension) . time();
                    $name = $name . $extension;
                    $request->image->move('images/coldDrinks-images/', $name);
                }
                ColdDrink::create([
                    'name' => $request->name,
                    'image' => 'coldDrinks-images/' . $name
                ]);
                return response()->json(['status' => 'success', 'msg' => $request->name . " Cold Drink Created Successfully!!"]);
            } catch (\Throwable $th) {
                return response()->json(['status' => 'failed', 'msg' => "error created Cold Drink"]);
            }
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function viewDrinkByID($id)
    {
        try {
            $data = ColdDrink::findOrFail($id);
            return response()->json(['status' => 'success', 'data' => $data]);
        } catch (\Throwable $th) {

            return response()->json(['status' => 'failed', 'msg' => "No Data Found!!"]);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function updateDrink(Request $request, $id)
    {
        $coldDrink = ColdDrink::findOrFail($id);
        if ($request->name) {
            $coldDrink->name = 'null';
            $coldDrink->save();
        }
        //validate incoming request 
        $validator = Validator::make($request->all(), [
            'name' => 'required|unique:products|max:25',
            'image' => 'required|image|mimes:jpeg,jpg,png,gif',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => 'val_err', 'val_err' => $validator->errors()]);
        } else {
            try {
                if ($request->hasFile('image')) {
                    $filename = $coldDrink->image;
                    if (!$filename == null) {
                        $file_path = rtrim(app()->basePath('public/' . 'images/' . $filename));
                        unlink($file_path);
                    }
                    $extension = "." . $request->image->getClientOriginalExtension();
                    $name = basename($request->image->getClientOriginalName(), $extension) . time();
                    $name = $name . $extension;
                    $request->image->move('images/coldDrinks-images/', $name);
                }
                $coldDrink->update([
                    'name' => $request->name,
                    'image' => 'coldDrinks-images/' . $name
                ]);
                return response()->json(['status' => 'success', 'msg' => $request->name . " cold Drinks updated Successfully!!"]);
            } catch (\Throwable $th) {
                return response()->json(['status' => 'failed', 'msg' => "error updated cold Drinks"]);
            }
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function deleteDrink($id)
    {
        $coldDrink = ColdDrink::findOrFail($id);
        $filename = $coldDrink->image;
        if (!$filename == null) {
            $file_path = rtrim(app()->basePath('public/' . 'images/' . $filename));
            unlink($file_path);
        }
        if ($coldDrink->delete()) {
            return response()->json(['status' => 'success', 'msg' => $coldDrink->name . " Product Deleted Successfully!!"]);
        } else {
            return response()->json(['status' => 'failed', 'msg' => "No Data Found!!"]);
        }
    }
}
