<?php

namespace App\Http\Controllers;

use App\Models\Product;
use Illuminate\Http\Request;
use Validator;
use File;
class ProductController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function getProduct()
    {
        try {
            $data = Product::orderBy('created_at', 'DESC')->get();
            return response()->json(['status' => 'success', 'data' => $data]);
        } catch (\Throwable $th) {

            return response()->json(['status' => 'failed', 'msg' => "No Data Found!!"]);
        }
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function addProduct(Request $request)
    {
        //validate incoming request 
        $validator = Validator::make($request->all(), [
            'category_id' => 'required',
            'name' => 'required|unique:products|max:25',
            'image' => 'required|image|mimes:jpeg,jpg,png,gif',
            'price' => 'required|max:11',
            'product_code' => 'required|max:11',
            'size1' => 'required|max:25',
            'size2' => 'required|max:25',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => 'val_err', 'val_err' => $validator->errors()]);
        } else {
            try {
                if ($request->hasFile('image')) {
                    $extension = "." . $request->image->getClientOriginalExtension();
                    $name = basename($request->image->getClientOriginalName(), $extension) . time();
                    $name = $name . $extension;
                    $request->image->move('images/products-images/', $name);
                }
                Product::create([
                    'category_id' => $request->category_id,
                    'name' => $request->name,
                    'price' => $request->price,
                    'product_code' => $request->product_code,
                    'size1' => $request->size1,
                    'size2' => $request->size2,
                    'image' => products-images . $name
                ]);
                return response()->json(['status' => 'success', 'msg' => $request->name . " Product Created Successfully!!"]);
            } catch (\Throwable $th) {
                return response()->json(['status' => 'failed', 'msg' => "error created Product"]);
            }
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function viewProduct($id)
    {
        try {
            $data = Product::findOrFail($id);
            return response()->json(['status' => 'success', 'data' => $data]);
        } catch (\Throwable $th) {

            return response()->json(['status' => 'failed', 'msg' => "No Data Found!!"]);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function productUpdate(Request $request, $id)
    {
        $product = Product::findOrFail($id);
        if ($request->name) {
            $product->name = 'null';
            $product->save();
        }
        //validate incoming request 
        $validator = Validator::make($request->all(), [
            'category_id' => 'required',
            'name' => 'required|unique:products|max:25',
            'image' => 'required|image|mimes:jpeg,jpg,png,gif',
            'price' => 'required|max:11',
            'product_code' => 'required|max:11',
            'size1' => 'required|max:25',
            'size2' => 'required|max:25',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => 'val_err', 'val_err' => $validator->errors()]);
        } else {
            try {
                if ($request->hasFile('image')) {
                    $filename = $product->image;
                    if (!$filename == null) {
                        $file_path = rtrim(app()->basePath('public/' . 'images/' . $filename));
                        unlink($file_path);
                    }
                    $extension = "." . $request->image->getClientOriginalExtension();
                    $name = basename($request->image->getClientOriginalName(), $extension) . time();
                    $name = $name . $extension;
                    $request->image->move('images/products-images/', $name);
                }
                $product->update([
                    'category_id' => $request->category_id,
                    'name' => $request->name,
                    'price' => $request->price,
                    'product_code' => $request->product_code,
                    'size1' => $request->size1,
                    'size2' => $request->size2,
                    'image' => 'products-images/' . $name
                ]);
                return response()->json(['status' => 'success', 'msg' => $request->name . " Product updated Successfully!!"]);
            } catch (\Throwable $th) {
                return response()->json(['status' => 'failed', 'msg' => "error updated Product"]);
            }
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function deleteProduct($id)
    {
        $product = Product::where('id',$id)->first();
        if($product){
             $filename = $product->image;
            if (!$filename == null) {
              $image_path = public_path("images/".$filename);
            unlink($image_path);
        }
        $del_product=Product::where('id',$id)->delete();
        return response()->json(['code'=>'200','status'=>'success','message'=>'data deleted successfully']);
    }
        return response()->json(['code'=>'301','status'=>'failed','message'=>'data not found']);
    }
}
